[![Support][support-badge]][support-url]
[![DOI][doi-badge-imgshield]][doi-url]
[![License][license-badge]][license-url]
[![Docker image tag][docker-image-tag-badge]][docker-image-url]
[![Docker pulls][docker-image-pull-badge]][docker-image-url]
[![Docker Stars][docker-image-stars-badge]][docker-image-url]
[![GitLab][gitlab-tag-badge]][gitlab-url]


[doi-badge-zenodo]: https://zenodo.org/badge/DOI/10.5281/zenodo.16760961.svg
[doi-badge-imgshield]: https://img.shields.io/badge/DOI-10.5281%20%2F%20zenodo.16760961-blue.svg?style=for-the-badge&logo=doi
[doi-url]: https://doi.org/10.5281/zenodo.16760961

[docker-image-tag-badge]: https://img.shields.io/docker/v/mayanedms/mayanedms?style=for-the-badge&sort=semver&logo=docker

[docker-image-url]: https://hub.docker.com/r/mayanedms/mayanedms

[docker-image-pull-badge]: https://img.shields.io/docker/pulls/mayanedms/mayanedms.svg?style=for-the-badge&logo=docker

[docker-image-stars-badge]: https://img.shields.io/docker/stars/mayanedms/mayanedms.svg?style=for-the-badge&logo=docker

[gitlab-pipelines-url]: https://gitlab.com/mayan-edms/mayan-edms/pipelines
[gitlab-tag-badge]:https://img.shields.io/gitlab/v/tag/mayan-edms%2Fmayan-edms?style=for-the-badge&sort=semver&logo=gitlab&label=GitLab
[gitlab-url]: https://gitlab.com/mayan-edms/mayan-edms

[pypi-badge]: https://img.shields.io/pypi/v/mayan-edms?style=for-the-badge&logo=python&label=PyPI
[pypi-url]: https://pypi.org/project/mayan-edms/

[license-badge]: https://img.shields.io/pypi/l/mayan-edms.svg?style=for-the-badge&logo=opensourceinitiative&logoColor=white&color=008800
[license-url]: https://gitlab.com/mayan-edms/mayan-edms/blob/master/LICENSE

[support-badge]: https://img.shields.io/badge/Get_support-brightgreen?style=for-the-badge
[support-url]: https://www.mayan-edms.com/support/


<a href="http://www.mayan-edms.com">
    <img align="center" height="200" width="200" src="https://gitlab.com/mayan-edms/mayan-edms/raw/master/docs/_static/mayan_logo_bw.png">
</a>

<p>
    The most advanced, scalable, and mature open source document management system.
<p>

<img align="center" src="https://gitlab.com/mayan-edms/mayan-edms/raw/master/docs/_static/overview.gif" width="400">

# Getting started

It is very easy to get started with Mayan EDMS, just deploy the official
Docker Compose file.

    curl https://gitlab.com/mayan-edms/mayan-edms/-/raw/master/docker/docker-compose.yml -O
    curl https://gitlab.com/mayan-edms/mayan-edms/-/raw/master/docker/.env -O
    docker compose up --detach

The complete documentation is available at: https://docs.mayan-edms.com/parts/installation.html

# Get the books

<a href="https://a.co/d/cqda9uu">
    <img align="center" src="https://m.media-amazon.com/images/I/61PAvrh303L._SL1293_.jpg" width="150">
</a>
<a href="https://a.co/d/9RMXyfn">
    <img align="center" src="https://m.media-amazon.com/images/I/61g21N5oQCL._SL1491_.jpg" width="150">
</a>

# Tutorials

For more in-depth articles, tutorials, and troubleshooting available in the Knowledge Base.


<a href="https://forum.mayan-edms.com/s/prod_Ogq3lYaoROC02Q">
    <img align="center" src="https://docs.mayan-edms.com/_static/knowledge-base.jpg" width="400">
</a>

Click the image or visit: https://forum.mayan-edms.com/s/prod_Ogq3lYaoROC02Q

# Important links

- [Homepage](http://www.mayan-edms.com)
- [Documentation](https://docs.mayan-edms.com)
- [Forum](https://forum.mayan-edms.com/)
- [Source code, issues, bugs](https://gitlab.com/mayan-edms/mayan-edms)

